"use strict";

this.name    = "AI Trading Fallback Datalogger";
this.version = "2.12";

/* ====================================================================================
			CONVERSION TABLE FOR COMMODITY NAMES TO LEDGER NUMBERS
======================================================================================= */

this.$commodities = ["food", "textiles", "radioactives", "slaves", "liquor_wines", "luxuries", "narcotics", "computers", "machinery", "alloys", "firearms", "furs", "minerals", "gold", "platinum", "gem_stones", "alien_items"];

/* ====================================================================================
			RECORD OF OPEN TRADES & LONG-RUN ACCOUNTS
======================================================================================= */

this.startUp = function()
	{
	delete this.startUp;
	if (worldScripts["AI Trading Assistant"])
		{
		delete this.$commodities;
		delete this.playerWillSaveGame;
		delete this.playerBoughtCargo;
		delete this.playerSoldCargo;
		return;
		}

	if (missionVariables.tradingAI_longRun)
		{
		this.$longRunAccounts = JSON.parse(missionVariables.tradingAI_longRun);
		}
	else
		{
		this.$longRunAccounts = [[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0],[0,0,0]];
		}

	var i, cargo, quantity, price;
	if (missionVariables.tradingAI_totalsBought && missionVariables.tradingAI_totalsSold)
		{
		this.$totalsBought = JSON.parse(missionVariables.tradingAI_totalsBought);
		this.$totalsSold   = JSON.parse(missionVariables.tradingAI_totalsSold);
		}
	else   // Copy $totalsBought from manifest...
		{
		this.$totalsBought = new Array(17);
		for (i = 0; i < this.$commodities.length; i++)
			{
			cargo = this.$commodities[i];
			this.$totalsBought[i] = manifest[cargo];
			}
		this.$totalsSold = [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0];
		}
	if (missionVariables.tradingAI_ledger)
		{
		this.$ledger = JSON.parse(missionVariables.tradingAI_ledger);
		}
	else   // First run, use market prices to set ledgers...
		{
		this.$ledger = [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0];
		for (i = 0; i < this.$commodities.length; i++)
			{
			cargo    = this.$commodities[i];
			quantity = manifest[cargo];
			if (quantity > 0)
				{
				price = player.ship.dockedStation.market[cargo].price;
				this.$ledger[i] = (quantity * price);
				}
			}
		}

	player.consoleMessage("AI Trading Fallback Datalogger is working.", 10);
	}

this.playerWillSaveGame = function ()
	{
	missionVariables.tradingAI_ledger       = JSON.stringify(this.$ledger);
	missionVariables.tradingAI_longRun      = JSON.stringify(this.$longRunAccounts);
	missionVariables.tradingAI_totalsBought = JSON.stringify(this.$totalsBought);
	missionVariables.tradingAI_totalsSold   = JSON.stringify(this.$totalsSold);
	}

/* ====================================================================================
			PLAYER BUYING CARGO
======================================================================================= */

this.playerBoughtCargo = function(cargo, quantity, unitPrice)
	{
	var ledgerNumber = this.$commodities.indexOf(cargo);
	this.$ledger[ledgerNumber] += (unitPrice * quantity); // Record payments.
	this.$totalsBought[ledgerNumber] += quantity;
	}

/* ====================================================================================
			PLAYER SELLING CARGO
======================================================================================= */

this.playerSoldCargo = function(cargo, quantity, unitPrice)
	{
	var ledgerNumber = this.$commodities.indexOf(cargo);
	this.$ledger[ledgerNumber] -= (unitPrice * quantity); // Record receipts.
	this.$totalsSold[ledgerNumber] += quantity;

	if (manifest[cargo] == 0) // Closing book...
		{
		// Transfer balance to long-run account...
		this.$longRunAccounts[ledgerNumber][0] -= this.$ledger[ledgerNumber]; // Yes, that is a minus sign.
		this.$longRunAccounts[ledgerNumber][1] += this.$totalsBought[ledgerNumber];
		this.$longRunAccounts[ledgerNumber][2] += this.$totalsSold[ledgerNumber];
		// Reset ledger...
		this.$ledger[ledgerNumber] = 0;
		this.$totalsBought[ledgerNumber] = 0;
		this.$totalsSold[ledgerNumber] = 0;
		}
	}

/* ====================================================================================
			COPYRIGHT NOTICE

	(C)2013, Wildeblood. All rights reserved. 
	Free to use, but DO NOT PROMULGATE MODIFIED VERSIONS.

This was created by some fellow with the user name "Wildeblood" on the Oolite forums, 
he'll tell you his real name if you bother to ask.
To use means to play with, modify or re-use in whole or in part, and to distribute freely.
To use DOES NOT imply to use for commercial gain, which would be a breach of copyright.
To promulgate means to make official announcements.
======================================================================================= */
